@@ -36,7 +36,7 @@ from .basehandler import BaseHandler, load
 from .basehandler import load as load_BaseHandler
 import atexit
 
-__version__ = "0.1.13"
+__version__ = "0.1.14"
 _eureka_client = None
 
 @atexit.register
@@ -90,6 +90,8 @@ class Server:
                         app_name=self.config.app_name,
                         instance_port=self.config.host_port if self.config.host_port else self.config.port,
                         instance_host=self.config.host_name,
+                        region=self.config.eureka_region,
+                        zone=self.config.eureka_region,
                     )
                     _eureka_client.start()
 
